@@ -1,4 +1,4 @@
-from .keyring import Key, Keyring
+from .keyring import Key, Keyring, validator
 
 from .minivault import MiniVault
 
@@ -13,6 +13,7 @@ from .vaultfactory import from_vault
 
 from .vaultstructs import *
 
+import distutils.sysconfig
 
 def clear_logs():
     import os
