@@ -57,9 +57,8 @@ class VaultFlags(str):
         f"""Flag to set if an input variable may be missing in a vault when it is accessed. In this case, the key will be sent to kwargs but it will be mapped to {None}."""
         warnings.warn(f"Using deprecated vault-flag {VaultFlags.input_var_can_be_missing.__name__}. "
                       f"This function is deprecated and will be removed in 2.0.0. Please use {VaultFlags.input_key_can_be_missing.__name__} instead",
-                      category=DeprecationWarning,
-                      stacklevel=2)
-        return VaultFlags(VaultFlags._INPUT_KEY_CAN_BE_MISSING)
+                      category=DeprecationWarning)
+        return VaultFlags.input_key_can_be_missing()
 
     @staticmethod
     def input_key_can_be_missing():
@@ -72,10 +71,10 @@ class VaultFlags(str):
         f"""Flag to clean return keys in a vault defined for a decorated function. This can be used during a cleanup stage. 
         Varvault will try to map the key to a default value for the valid type, like for example str(), or list(). If it doesn't work, the key will be mapped to {None}."""
         warnings.warn(f"Using deprecated vault-flag {VaultFlags.clean_return_var_keys.__name__}. "
-                      f"This function is deprecated and will be removed in 2.0.0. Please use {VaultFlags.clean_return_var_keys.__name__} instead",
+                      f"This function is deprecated and will be removed in 2.0.0. Please use {VaultFlags.clean_return_keys.__name__} instead",
                       category=DeprecationWarning,
                       stacklevel=2)
-        return VaultFlags(VaultFlags._CLEAN_RETURN_KEYS)
+        return VaultFlags.clean_return_keys()
 
     @staticmethod
     def clean_return_keys():
@@ -139,4 +138,3 @@ class VaultFlags(str):
         """Flag to tell varvault when using a vaulter-decorated function and not returning objects for all keys to not fail and just set the keys defined.
          If this is set, the return variables MUST be inside a MiniVault object, otherwise varvault cannot determine what variable belongs to what key."""
         return VaultFlags(VaultFlags._RETURN_KEY_CAN_BE_MISSING)
-
